function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function H(depth) {
  return Array(depth).fill('#').join('');
}

function buildOptions(options) {
  return "| Flag | Type | Description |\n| - | - | - |\n" + options.map(function (option) {
    var ways = ["`--" + option.name + "`"];

    if (option.alias) {
      ways.push("`-" + option.alias + "`");
    }

    return "| " + ways.join(', ') + " | " + (option.typeLabel ? option.typeLabel.replace(/\|/g, '\\|') : option.type.name) + " | " + option.description + " |";
  }).join('\n');
}

function buildExamples(command) {
  if (!command.examples) {
    return;
  }

  return "" + command.examples.map(function (example) {
    if (typeof example === 'string') {
      return "```sh\n" + example + "\n```";
    }

    return example.desc + "\n\n ```sh\n" + example.example + "\n```";
  }).join('\n\n');
}

function createDocsForCommand(command, options) {
  var depth = options.depth;
  var output = H(1 + depth) + " `" + command.name + "`\n\n" + command.description + "\n\n";

  if ('commands' in command) {
    output += H(2 + depth) + " Commands\n\n" + command.commands.map(function (c) {
      return "  - **" + c.name + "** - " + c.description;
    }).join('\n') + "\n\n";
  }

  if (command.options) {
    output += H(2 + depth) + " Options\n\n" + buildOptions(command.options) + "\n\n";
  }

  if ('examples' in command) {
    output += H(2 + depth) + " Examples\n\n" + buildExamples(command) + "\n\n";
  }

  if ('commands' in command) {
    var globalOptions = command.options || [];
    command.commands.map(function (c) {
      var commandOptions = c.options || [];
      output += createDocsForCommand(options.includeGlobalOptionsForSubCommands ? _extends({}, c, {
        options: [].concat(globalOptions, commandOptions)
      }) : c, _extends({}, options, {
        depth: options.depth + 1
      }));
    });
  }

  if ('footer' in command) {
    if (typeof command.footer === 'string') {
      output += command.footer;
    } else {
      var sections = Array.isArray(command.footer) ? command.footer : [command.footer];
      sections.forEach(function (section) {
        if (section) {
          if (section.header) {
            output += H(2 + depth) + " " + section.header + "\n\n";
          }

          output += ('optionList' in section && buildOptions(section.optionList) || 'content' in section && section.content) + "\n\n";
        }
      });
    }
  }

  return output;
}

var defaultOptions = {
  depth: 0,
  includeGlobalOptionsForSubCommands: false
};

function commandLineDocs(params, userOptions) {
  if (userOptions === void 0) {
    userOptions = {};
  }

  var options = _extends({}, defaultOptions, userOptions);

  return createDocsForCommand(params, options);
}

export default commandLineDocs;
//# sourceMappingURL=command-line-docs.esm.js.map
